package it.inaf.oats.ia2.tap.tsm.pageutil;

import it.inaf.oats.ia2.tap.tsm.model.Credentials;
import java.io.IOException;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 *
 * @author Sonia Zorba <zorba at oats.inaf.it>
 */
public class InsertCredentials {

    private final List<String> errors;
    private Credentials credentials;

    public InsertCredentials() {
        errors = new ArrayList<String>();
    }

    public void load(HttpServletRequest request, HttpServletResponse response) throws IOException {
        String hostname = request.getParameter("hostname");
        String portStr = request.getParameter("port");
        String username = request.getParameter("username");
        String password = request.getParameter("password");

        credentials = new Credentials();

        errors.clear();

        if (hostname != null || portStr != null || username != null) {
            if (hostname == null || hostname.equals("")) {
                errors.add("hostname can't be empty");
            } else {
                credentials.setHostname(hostname);
            }

            if (portStr == null || portStr.equals("")) {
                errors.add("port can't be empty");
            }
            int port;
            try {
                port = Integer.parseInt(portStr);
                credentials.setPort(port);
            } catch (NumberFormatException e) {
                errors.add("invalid port value");
            }

            if (username == null || username.equals("")) {
                errors.add("Username can't be empty!");
            } else {
                credentials.setUsername(username);
            }

            if (password == null) {
                password = "";
            }
            credentials.setPassword(password);

            if (errors.isEmpty()) {
                try {
                    SelectTapSchema selectTapSchema = new SelectTapSchema(credentials.getConnection());
                    request.getSession().setAttribute("SELECT_TAP_SCHEMA", selectTapSchema);
                    response.sendRedirect("selectTapSchema.jsp");
                } catch (SQLException e) {
                    errors.add("Connection error: " + e.getMessage());
                }
            }
        }
    }

    public List<String> getErrors() {
        return errors;
    }

    public Credentials getCredentials() {
        return credentials;
    }
}
